"""
Created on Fri May 29 15:20:50 2020
sovrapposizione grafici derivata su variazioni giornaliere
@author: lorenzo
"""

# pacchetti
import json
import matplotlib.pyplot as plt
import numpy as np
from scipy.optimize import curve_fit


# definizione della funzione derivata della logistica
def logistica(x, a, b, c):
    return a / (1 + b * np.exp(-c * x))


def derivata(x, a, b, c):
    return a * b * c * np.exp(-c * x) / (1 + b * np.exp(-c * x)) ** 2


# modificare tale data
dataISO = '20200601'
# modificare eventualmente il nome del file
nomeFile = 'datiRegionali' + dataISO

# utilizzata nel grafico finale
codificaItaliana = dataISO[6:] + '-' + dataISO[4:6] + '-' + dataISO[:4]

# viene letto il file json
with open(nomeFile + '.json') as f:
    dati = json.load(f)

# si estraggono i dati totale_casi della regione Veneto
ydata = []
for elemento in dati:
    if elemento['denominazione_regione'] == "Veneto":
        ydata.append(elemento['totale_casi'])

# calcolo delle variazioni giornaliere
ypostData = np.roll(ydata, -1)
delta = ypostData - ydata
variazioni = delta[:-1]

numGiorni = len(ydata)

giorni = np.linspace(1, numGiorni - 1, numGiorni - 1)

xdata = np.linspace(1, numGiorni, numGiorni)
param, covarianza = curve_fit(logistica, xdata, ydata)

# predispone la figura e il grafico dei singoli dati
fig, ax = plt.subplots()

# label della curva derivata
labs = 'fit: a = %5.2f,\nb = %5.2f, c = %5.2f' % tuple(param)
# grafico della curva derivata
plt.plot(giorni, derivata(giorni, param[0], param[1], param[2]), 'C1', linewidth=3., label=labs)

ax.plot(giorni, variazioni, marker='o', markersize=2, mec='b', color='cornflowerblue', label='nuovi positivi')
ax.fill_between(giorni, 0, variazioni, where=variazioni > 0, facecolor='aliceblue')
ax.set_title('Veneto: variazione giornaliera contagio\ne curva derivata')
ax.set_xlabel('giorni dal 24 febbraio 2020')
ax.set_ylabel('nuovi positivi giornalieri')
ax.grid(color='.85', linestyle='-', linewidth=1)
ax.text(70, 350, 'aggiornato il\n' + codificaItaliana)

plt.legend()
plt.show()
# plt.savefig('deltaVeneto.pdf')
